function [R,C,EY]=Dirichlet_residuals(Y,alphas)
%standardized univariate and composite residuals for Dirichlet-distributed
%data
%SYNTAX
%[R,C,EY]=Dirichlet_residuals(Y,alphas)
%INPUTS
%Y is an n x k matrix of observations on Dirichlet-distributed data for n
%individuals, each with k components
%alphas is an n x k matrix of estimated Dirichlet parameters for each
%individual
%OUTPUTS
%R is an n x k matrix of standardized univariate residuals
%C is an n x 1 vector of composite residuals
%EY is an n x k matrix of expected values for each component on each
%individual
%SOURCE
%Gueorguieva et al 2008 Comp. Stat. Data Anal. 52:5344-5355

%compute expected value for each component
k=size(Y,2);
alphasum=sum(alphas,2);
asm=alphasum(:,ones(1,k));
EY=alphas./asm;

VY=EY.*(1-EY)./(1+asm);%compute variance for each component
R=(Y-EY)./sqrt(VY);%compute standardized univariate residuals
C=sum(R.^2,2);%compute composite residuals