function [fx,q]=Nystrom_distribution(m,eigvec,eigval,alphas,Gw,newfig,fontsize,doplot)
%use Nystrom extension to plot an approximation to the stationary
%distribution (eigenfunction) on the simplex
%SYNTAX
%[fx,q]=Nystrom_distribution(m,eigvec,eigval,alphas,Gw,newfig,fontsize,doplot)
%INPUTS
%m is the square root of the number of mesh points we want
%eigvec is the eigenvectors of the matrix Dw as column vectors
%eigval is the corresponding eigenvalues as a diagonal matrix
%alphas is the Dirichlet parameters estimated at the Gauss points we used
%to approximate the eigenvalues
%Gw is the Gauss weights for the points we used
%newfig (optional): if 1 (default), plot on a new figure
%fontsize (optional): font size for axis labels
%doplot (optional): if 0, don't plot at all
%OUTPUTS
%fx is the approximated eigenfunction (scaled so that it integrates to 1)
%q is the points at which the eigenfunction is estimated
%also produces a figure in which the eigenfunction is represented on the
%simplex by triangles of which points q are the centres
%USES
%generate_meshpoints.m
%computeD2.m
%plot_coral_distribution.m

if nargin<6
    newfig=1;
end
if nargin<7
    fontsize=18;
end
if nargin<8
    doplot=1;
end
[q,v]=generate_meshpoints(m);%generate a regular grid of mesh points
[em,i]=max(diag(eigval));%index of largest eigenvalue (em is the value, should be close to 1)
fy=eigvec(:,i);%the corresponding eigenvector
fy=fy/(Gw'*fy);%rescale the eigenvector so it integrates to 1 over the Gauss points
D=computeD2(q,alphas,0);%compute the kernel for transitions from points at which alphas were estimated to points at which we want to evaluate. Don't normalize
Dw=D*diag(Gw);
fx=Dw*fy;%Nystrom extension
fx=fx/em;%em should be very close to 1 anyway
if doplot
    plot_coral_distribution(v,fx,newfig,fontsize);%plot the resulting distribution
end