function [simX,simY]=constructXY(simreefid,simdata,simyear)
%SYNTAX
%[simX,simY]=construxtXY(simreefid,simdata,simyear)
%INPUTS
%All the following have the same number of rows: each row
%corresponds to an observation on a single (simulated) reef in a single
%year
%simreefid is a unique id for each sequence of observations in the same
%simulation
%simdata is a matrix with three columns: proportions of coral, algae and
%others in a single simulated reef in a single year
%simyear is year of observation
%OUTPUTS
%simX is a matrix where each row is an observation, with columns:
%simreefid simyear coral algae others
%for observations that have another observation one year later on the same
%reef
%simY is a matrix in the same form, but such that row i of simY corresponds to
%the state of the reef in row i of simX one year later
%NOTES
%based on readBruno3.m: more complicated than we really need, but easier
%than writing from scratch

coral=simdata(:,1);
algae=simdata(:,2);
other=simdata(:,3);

%filter to runs of observations at one-year intervals
filter=zeros(length(simyear));
filterX=zeros(length(simyear));
filterY=zeros(length(simyear));
uniqueid=unique(simreefid);
for i=1:length(uniqueid)%each reef
   reefi=find(simreefid==uniqueid(i));%find this reef
   if length(reefi)>1%more than one observation for this reef
       deltat=diff(simyear(reefi));%intervals between years in which this reef was observed
       filter(reefi(1))=(deltat(1)==1);%retain first observation only if next is one year later
       filterX(reefi(1))=filter(reefi(1));
       for j=2:length(reefi)-1%each observation for this reef
           filter(reefi(j))=(deltat(j-1)==1 | deltat(j)==1);%retain this observation if it's one year after the preceding, or one year before the next, observation
           filterX(reefi(j))=(deltat(j)==1);%belongs in X if the next observation is one year later
           filterY(reefi(j))=(deltat(j-1)==1);%belongs in Y if the preceding observation is one year before
       end
       filter(reefi(length(reefi)))=(deltat(length(reefi)-1)==1);%retain last observation?
       filterY(reefi(length(reefi)))=filter(reefi(length(reefi)));%belongs in Y if the preceding observation was one year before
   else%only one observation for this reef: discard
       filter(reefi)=0;
       filterX(reefi)=0;
       filterY(reefi)=0;
   end
end
X=[simreefid(logical(filterX)),simyear(logical(filterX)),coral(logical(filterX)),algae(logical(filterX)),other(logical(filterX))];
Y=[simreefid(logical(filterY)),simyear(logical(filterY)),coral(logical(filterY)),algae(logical(filterY)),other(logical(filterY))];
simX=X;
simY=Y;
