function k_cv = cross_valid_neigh( x, y, Ker, Dist)

% cross-validation method of the local maximum likelihood estimation
% for parameters of the Dirichlet distribution of the future state of the
% reef given its current state; the result is the estimated optimal 
% proportion of neighbours to be used in local ML estimation   
%
%
%SYNTAX
% k_cv = cross_valid_neigh( x, y, Ker, Dist)
%
% INPUT
%
% x - 3 column matrix with the initial state of the reef
% y - state of the reef after (approximatelly) one year (so that each row
%   in y corresponds to a row in x)
% Ker - kernel function (currently probably only 'epanechnikov' works)
% Dist - a distence function on the simplex; two options 'distTaxi' or
%   'distAt3'
%
% OUTPUT
% k_cv - cross-validation estimate of the optimal proportion of
%       neightbours to use in estimation
%
%USES
%distTaxi.m
%distAl3.m
%epanechnikov.m
% dirMLlocKerNeigh

%%%%% CODE

n1 = size(y,1);

% offset zeros
[id1,id2] = find( y == 0 );
y(id1,id2) = 1e-12;
y(id1,1:(id2-1)) = y(id1,1:(id2-1)) - .5e-12;
y(id1,(id2+1):3) = y(id1,(id2+1):3) - .5e-12;


%%%% INITIAL VALUES FOR OPTIMISATION
options = optimset('MaxIter', 50); 

%%%%% CROSS-VALIDATION
%%%%% BANDIWDTH

%h_cv = fminunc(@get_neg_loglike,H);%,H(1),H(end),options);
k_cv = fminbnd(@get_neg_loglike,0,1,options);

%lH = length(H);
%for ih = 1:lH,
 %   NLcv(ih) = get_neg_loglike(H(ih));
%end

%plot(H,NLcv)

%h_cv = H( NLcv==min(NLcv) );

%NLcv

function neg_loglike = get_neg_loglike(k)
		% get negative loglikelihood for this value of h
		% this is a nested function, so it shares variables!
		for i = 1:n1,
            try
                tmp = dirMLlocKerNeigh( x(i,:), x([1:(i-1),(i+1):n1],:),...
                    y([1:(i-1),(i+1):n1],:), rand(1,9)*3, k, Ker, Dist);
            catch ME1
                'tried'
            end
                tmp = dirMLlocKerNeigh( x(i,:), x([1:(i-1),(i+1):n1],:),...
                    y([1:(i-1),(i+1):n1],:), rand(1,9), k, Ker, Dist);
            
                est(i,:) = tmp.estims;
       end
        neg_loglike = nloglike(y,est); % return MISE for this h
        %k
end

function l = nloglike(y,alphas)
    % calculates log-likelihood for Dirichelet distribution
    % size of y and alphas must be the same
    logy = log(y);
    logB = sum(gammaln(alphas),2) - gammaln(sum(alphas,2));

    % negative loglikelihood
    l = sum(logB - diag((alphas - 1) * logy'));
end

end