function f=ddirichlet2(p,alpha,logZ)
%Dirichlet density: this version evaluates using gammaln function
%SYNTAX
%f=ddirichlet2(p,alpha,logZ)
%INPUTS
%p is a vector of coordinates of the point for which we want the density
%(sums to 1)
%alpha is a vector of non-negative parameters for the Dirichlet
%distribution
%Optionally, logZ is the log of the normalization constant such that
%f=1/Z*prod(p.^(alpha-1))
%logZ is calculated if not supplied
%OUTPUTS
%f is the Dirichlet density at point p
%NOTES
%4/8/10: return 0 for values outside the domain
%7/3/11: should only set return value to 0 outside, not on, boundary of
%domain

if nargin<3%logZ not supplied
    logZ=sum(gammaln(alpha))-gammaln(sum(alpha));%compute the normalization constant    
end
if any(p<0)%density is outside boundaries
    f=0;
else
    f=exp(sum(log(p).*(alpha-1))-logZ);%Dirichlet density for this point
end
