function [alphas,exitflags,timetaken]=estimate_alpha_neigh(X,Y,k,Ker,Dist)
%estimate Dirichlet parameters for observations using specified proportion
%of neighbours
%SYNTAX
%[alphas,exitflags,timetaken]=estimate_alpha_neigh(X,Y,k,Ker,Dist)
%INPUTS
%X is a matrix where each row is an observation, with columns:
% reefid year coral algae others
% for observations that have another observation one year later on the same
% reef
%Y is a matrix in the same form, but such that row i of Y corresponds to
% the state of the reef in row i of X one year later
%init is initial value for optimisation algorithm; this should be a column vector with 9 elements
%k (scalar) is the proportion of observations to include in the local neighbourhood
%for each observation
%Ker - kernel function (currently probably only 'epanechnikov' works)
%Dist - a distance function on the simplex; two options 'distTaxi' or
%'distAt3'
%OUTPUTS
%alphas is an n x 3 matrix of estimated Dirichlet parameters for the fate
%of each observation
%exitflags is an n x 1 vector of optimizer status on exit
%timetaken is clock time used
%USES
%dirMLlocKerNeigh.m

tzero=clock;
n=size(X,1);
Al=cell(n,1);
alphas=zeros(n,3);
exitflags=zeros(n,1);
for ii=1:n
    Al{ii} = dirMLlocKerNeigh(X(ii,3:5),X(:,3:5),Y(:,3:5),zeros(9,1),k,Ker,Dist);%estimate Dirichlet for this point
    exitflags(ii)=Al{ii}.exitflag;
    alphas(ii,:)=Al{ii}.estims';
end
timetaken=etime(clock,tzero);