function [alphas,exitflags,Al,timetaken]=estimate_meshalphaNeigh(q,X,Y,init,k,Ker,Dist)
%estimate parameters of local Dirichlet distribution for all mesh points q
%This version: define proportion of observations to include in the local
%neighbourhood for each point, instead of fixed bandwidth
%SYNTAX
%[alphas,exitflags,Al,timetaken]=estimate_meshalphaNeigh(q,X,Y,init,k,Ker,dist)
%INPUTS
%q is an n x 3 matrix, with row q_j being the coordinates of a mesh point
%on the triangular simplex.
%X is a matrix where each row is an observation, with columns:
% reefid year coral algae others
% for observations that have another observation one year later on the same
% reef
%Y is a matrix in the same form, but such that row i of Y corresponds to
% the state of the reef in row i of X one year later
%init is initial value for optimisation algorithm; this should be a column vector with 9 elements
%k is the proportion of observations to include in the local neighbourhood
%for each mesh point
%Ker - kernel function (currently probably only 'epanechnikov' works)
%Dist - a distance function on the simplex; two options 'distTaxi' or
%'distAt3'
%OUTPUTS
%alphas is an n x 3 array of the estimated Dirichlet parameters
%alpha1, alpha2, alpha3 (columns) for each point (row) in q
%exitflags is an n x 1 array of the values of the optimizer exit flags from
%the fitstructs in Al (positive values mean it probably worked OK)
%Al is an n x 1 cell array of structures. Element j is the structure
%fitstruct estimated by dirMLlocKer2.m for point q_j.
%timetaken is clock time used
%USES
%dirMLlocKerNeigh.m

tzero=clock;
n=size(q,1);
Al=cell(n,1);
alphas=zeros(n,3);
exitflags=zeros(n,1);
for ii = 1:n
    Al{ii} = dirMLlocKerNeigh(q(ii,:),X(:,3:5),Y(:,3:5),init,k,Ker,Dist);
    exitflags(ii)=Al{ii}.exitflag;
    alphas(ii,:)=Al{ii}.estims';
end
timetaken=etime(clock,tzero);