function [q,v]=generate_meshpoints(ncut)
%generate mesh points to approximate the integral
%SYNTAX
%[q,v]=generate_meshpoints(ncut)
%INPUTS
%ncut is number of cut points on each axis
%OUTPUTS
%q is an (ncut+1)^2 x 3 matrix, where each row j is the x, y, and z
%components of mesh point q_j.
%v is an (ncut+1)^2 x 9 matrix. For a given row i of q, cols 1:3, 4:6, and
%7:9 of the corresponding row of v are the vertices of the triangle of
%which q(i,:) is the centre

q=zeros((ncut+1)^2,3);
v=zeros((ncut+1)^2,9);
x=0;
y=0;
c=1;
ny=ncut+2;
inc=1/(ncut+1);%step size
for i=1:ncut+2
    for j=1:ny-1
        
        %point on first row: (x,y,1-x-y) is lower left corner of triangle
        z=max(1-x-y,0);%we might have rounding errors that take this just below 0
        pa=[x,y,z];%full coordinates of point        
        zn=max(z-inc,0);
        pb=[x+inc,y,zn];
        pc=[x,y+inc,zn];
        v(c,:)=[pa,pb,pc];
        
        %centre of triangle
        xx=x+inc/3;
        yy=y+inc/3;
        zz=1-xx-yy;
        q(c,:)=[xx,yy,zz];
        c=c+1;
        
        %point on second row
        xx=xx+inc/3;
        yy=yy+inc/3;
        zz=1-xx-yy;
        if zz>=0%inside simplex
            pd=[x+inc,y+inc,z-2*inc];
            v(c,:)=[pb,pc,pd];
            q(c,:)=[xx,yy,zz];
            c=c+1;
        end
        y=y+inc;
    end
    x=x+inc;
    y=0;
    ny=ny-1;
end