function [Cnorm,Cnorm2]=getCnorm(x)
%get norm of a composition
%SYNTAX
%[Cnorm,Cnorm2]=getCnorm(x)
%INPUTS
%x is a row vector composition, or a matrix in which each row is a
%composition
%OUTPUTS
%Cnorm is the norm of each row of x, as defined in Pawlowsky-Glahn et al
%2007, Lecture notes in Compositional Data Analysis, p.14
%Cnorm2 is the norm defined by Billheimer et al 01, JASA 96:1205-1214
%NOTES
%1. I'm sure there are more compact ways of doing this...
%2. Aitchison 2003 (postscript to reprint of his book) has yet another
%slightly different norm

[N,D]=size(x);
d=D-1;
Cnorm=zeros(N,1);
Cnorm2=zeros(N,1);
Ninv=eye(d)-1/d*ones(d,1)*ones(1,d);
lx=log(x);
for n=1:N
    theta=alr(x(n,:));
    Cnorm2(n)=theta*Ninv*theta';
    for i=1:D-1
        for j=i+1:D
            Cnorm(n)=Cnorm(n)+(lx(n,i)-lx(n,j))^2;
        end
    end
end
Cnorm=sqrt(Cnorm/D);
Cnorm2=sqrt(Cnorm);

