function p=getperturbation(X,Y)
%find the perturbation vectors required to go from state X to fate Y
%SYNTAX
%p=getperturbation(X,Y)
%INPUTS
%X is a matrix where each row is an observation, with columns:
% reefid year coral algae others
% for observations that have another observation one year later on the same
% reef
%Y is a matrix in the same form, but such that row i of Y corresponds to
% the state of the reef in row i of X one year later
%OUTPUTS
%p is an n x 3 matrix, where rows are pairs of observations, such that the
%ith row of p is the perturbation needed to go from X to Y
%NOTES
%we discard any rows where either X or Y has a zero element

%we only need the coral, algae, others cols
X=X(:,3:5);
Y=Y(:,3:5);

%discard rows with zeros
xi=~(any(X==0,2));
yi=~(any(Y==0,2));
ri=logical(xi.*yi);
X=X(ri,:);
Y=Y(ri,:);

p=Y./X;
ps=sum(p,2);
ps=ps(:,ones(1,3));
p=p./ps;%perturbation vector
    
