function mgm=makedistmovie2(f0,v,gv,fx,tmax,newfig,fontsize,mglim)
%make a movie of changes in density over time
%(actually the movie was dull so ended up as panels)
%SYNTAX
%mgm=makedistmovie2(f0,v,gv,fx,tmax,newfig,fontsize,mglim)
%INPUTS
%f0 is a matrix whose rows are the latest values of coral, algae, and
%others observed on each reef
%gv is a matrix with entry i,j the density at the ith visual grid point at time j
%v is a matrix of visual grid points (each row is a point, cols are coral,
%algae, free space)
%fx is stationary distribution
%tmax is max time step (make it a square number -1 please)
%if newfig (optional) is 1, draw it on a new figure
%fontsize (optional) is font size for axis labels
%mglim (optional) is a vector of min and max for colour scale
%OUTPUTS
%plots difference in probability density at each time point (current -
%stationary)
%also returns mgm, the max absolute difference in probability density
%between stationary and current distributions, over times in 1:tmax
%USES
%xytoternary.m
%label_ternary_axes

if nargin<6
    newfig=1;
end
if nargin<7
    fontsize=18;
end
if nargin<8
    mglim=[];
end

if newfig
    figure(1);
    clf;
end

%plot the discrete distribution at time 0
subplot(sqrt(tmax+1),sqrt(tmax+1),1);
a=2/3*sin(pi/3);
xv=[-a a 0 -a];%triangle edges
yv=[-1/3 -1/3 2/3 -1/3];
plot(xv,yv,'k-');%plot edges
axis equal;
axis off;
hold on;
p=xytoternary(f0);
plot(p(:,1),p(:,2),'r.');
panel_label('a: \itt\rm_0');
label_ternary_axes({'coral','algae','others'},fontsize);%axis labelling

mgm=0;
for t=1:tmax
   mgv=diffplot(v,gv,fx,tmax,t);
   if mgv>mgm
       mgm=mgv;
   end
   panel_label([char(double('a')+t),': \itt\rm_0+',num2str(t)]);
   label_ternary_axes({'coral','algae','others'},fontsize);%axis labelling
end

%same colour scale on all panels
for t=1:tmax
    subplot(sqrt(tmax+1),sqrt(tmax+1),t+1);
    if isempty(mglim)
        caxis([-mgm,mgm]);
    else
        caxis(mglim);
    end
end
h=colorbar;
ps=get(h,'position');
set(h,'location','manual','position',[ps(1)+0.1 ps(2) 0.01 ps(4)]);
%colorbar('location','manual');%manual stops it changing subplot size
end

%plot difference between current and stationary distributions
%returns max absolute difference
function mgv=diffplot(v,gv,fx,tmax,t)
    subplot(sqrt(tmax+1),sqrt(tmax+1),t+1);
    a=2/3*sin(pi/3);
    xv=[-a a 0 -a];%triangle edges
    yv=[-1/3 -1/3 2/3 -1/3];
    plot(xv,yv,'k-');%plot edges
    axis equal;
    axis off;
    hold on;
    
    %use the following if we want to plot difference from endpoint
    gvec=gv(:,t)-fx;
    colormap(cool);
    mgv=max(abs(gvec(:)));
    n=size(v,1);
    for ii=1:n
       pa=xytoternary(v(ii,1:3));
       pb=xytoternary(v(ii,4:6));
       pc=xytoternary(v(ii,7:9));
       patchcoord=[pa;pb;pc];
       patch(patchcoord(:,1),patchcoord(:,2),gvec(ii)*ones(3,1),'edgecolor','flat');
    end
    %colorbar;
    %label_ternary_axes({'coral','algae','others'});%axis labelling    
end