function plot_coral_distribution(v,f,newfig,fontsize,ccax,cbar)
%plot a distribution of coral reefs (e.g. an estimated stationary distribution)
%over the simplex
%SYNTAX
%plot_coral_distribution(v,f,newfig,fontsize,ccax,cbar)
%INPUTS
%v is an n x 9 matrix of vertices for triangles that cover the simplex,
%arranged so that in row i, cols 1:3 are the coordinates of the first
%vertex, 4:6 are the coordinates of the second vertex, and 7:9 are the
%coordinates of the third vertex
%f is an n x 1 vector of values (e.g. stationary densities) for the points
%at the centre of the corresponding triangles
%newfig (optional): if 1 (default), plot on a new figure
%fontsize (optional): font size for axis labels
%ccax (optional) is min and max values for color map
%if cbar (optional, default 1) is 1, draw a color bar
%OUTPUTS
%a ternary plot divided into triangles defined by vertices v and coloured
%by the values in f (uses flat shading)
%USES
%xytoternary.m
%label_ternary_axes.m

if nargin<3
    newfig=1;
end
if nargin<4
    fontsize=18;
end
if nargin<5
    ccax=[];
end
if nargin<6
    cbar=1;
end

a=2/3*sin(pi/3);
xv=[-a a 0 -a];%triangle edges
yv=[-1/3 -1/3 2/3 -1/3];
if newfig
    figure(1);
    clf;
end

plot(xv,yv,'k-');%plot edges
axis equal;
axis off;
hold on;
colormap(pink);
if ~isempty(ccax)
    caxis(ccax);
end
n=size(v,1);
for ii=1:n
   pa=xytoternary(v(ii,1:3));
   pb=xytoternary(v(ii,4:6));
   pc=xytoternary(v(ii,7:9));
   patchcoord=[pa;pb;pc];
   patch(patchcoord(:,1),patchcoord(:,2),f(ii)*ones(3,1),'edgecolor','flat');
end

if cbar
    h=colorbar;
    ps=get(h,'position');
    set(h,'location','manual','position',[ps(1)-0.1 ps(2) 0.01 ps(4)]);
end
label_ternary_axes({'coral','algae','others'},fontsize);%axis labelling