function plot_lagged_residuals(X,R,span,fignums,fsize)
%plot standardized univariate residuals against state in the prediction
%year and in the previous year
%SYNTAX
%plot_lagged_residuals(X,R,span,fignums,fsize)
%INPUTS
%X has columns reefid, year, coral, algae, others
%R is standardized univariate residuals for coral, algae, and others (for
%predictions made from year t about year t+1)
%span is proportion of points to use in lowess smoothing
%fignums (optional, defaults 1 and 2) is the figure numbers in which the
%outputs are plotted
%fsize (optional) is font size
%OUTPUTS
%figure 1 plots each component of reef composition at time t-1 (the state preceding the one used to make predictions) against the
%residual at time t+1.
%figure 2 plots each component of reef composition at time t (the
%state used to make predictions) against the residual at time t+1
%lowess smoother lines are included on each plot

if nargin<4
    fignums=[1,2];
end
if nargin<5
    fsize=18;
end
nr=size(R,1);
figure(fignums(1));
clf;
names={'Coral','Algae','Others'};
labels={'a','b','c','d','e','f','g','h','i','j'};
Xshift=X(2:nr,:);
Rshift=R(2:nr,:);
ind=logical(X(1:end-1,1)==Xshift(:,1) & X(1:end-1,2)==Xshift(:,2)-1);%is there an observation from the same reef a year ago?
smoothvals=[X(ind,3:5),Rshift(ind,:)];
for j=1:3
    for k=1:3
        subplot(3,3,k+(j-1)*3);
        yy=smooth(smoothvals(:,j),smoothvals(:,k+3),span,'lowess');
        [x,i]=sort(smoothvals(:,j));
        plot(smoothvals(:,j),smoothvals(:,k+3),'k.',x,yy(i),'r-');%state last year against residual for predicted state next year
        xlabel([names{j},' (t-1)']);
        ylabel([names{k},' residual (t+1)']);
        %xl=get(gca,'xlim');
        xl=[0 1];
        yl=get(gca,'ylim');
        text(xl(1)+0.1*(xl(2)-xl(1)),yl(2)-0.1*(yl(2)-yl(1)),labels{k+(j-1)*3})
        set(gca,'xlim',xl,'ylim',yl,'fontsize',fsize);
    end
end

figure(fignums(2));
clf;
for j=1:3
    for k=1:3
        subplot(3,3,k+(j-1)*3);
        yy=smooth(X(:,j+2),R(:,k),span,'lowess');
        [x,i]=sort(X(:,j+2));
        plot(X(:,j+2),R(:,k),'k.',x,yy(i),'r-');%current state against residual for predicted state next year
        xlabel([names{j},' (t)']);
        ylabel([names{k},' residual (t+1)']);
%        xl=get(gca,'xlim');
        xl=[0 1];
        yl=get(gca,'ylim');
        text(xl(1)+0.1*(xl(2)-xl(1)),yl(2)-0.1*(yl(2)-yl(1)),labels{k+(j-1)*3})
        set(gca,'xlim',xl,'ylim',yl,'fontsize',fsize);
    end
end
