function [Al_X0,q,v] = plotalphas2(X,Y,k,m)
% generate estimated surfaces for 3 alphas for data X and Y; the
% calculated values Al_X0 and coordinates q,v are returned
%Based on Kamila's plotalphas.m, but with deterministic initialization that
%matches what we did to fit the model, and a triangular grid
%SYNTAX
%[Al_X0,q,v] = plotalphas2(X,Y,k,dx)
%INPUT
%
% X, Y - starting and end data points
% k - number of nearest numbers to be used in estimation
% m is number of cut points on each axis for regular grid of mesh points
% OUTPUT
%
% Al_X0 - three column matrix with estimated values of alpha on a regular
%   grid
%q is an (ncut+1)^2 x 3 matrix, where each row j is the x, y, and z
% components of mesh point q_j.
% v is an (ncut+1)^2 x 9 matrix. For a given row i of q, cols 1:3, 4:6, and
% 7:9 of the corresponding row of v are the vertices of the triangle of
% which q(i,:) is the centre
% The estimated surfaces are plotted in separate figures 
% WARNING: this functions uses a loop and prints out a number at each
% iteration, just to make sure it's still working!!!
%USES
%generate_meshpoints.m
%dirMLlocKerNeigh.m

[q,v]=generate_meshpoints(m);%generate a regular grid of mesh points
n=size(q,1);
Al_X0=zeros(n,3);
% find estimates
for ii = 1:n
    tmp = dirMLlocKerNeigh(q(ii,:),X(:,3:5),Y(:,3:5),zeros(9,1),k,'epanechnikov','distTaxi');
    Al_X0(ii,:) = tmp.estims';
end

