function residsbytime2(Y,C,R,fsize,newfig)
%plot composite and univariate residuals by prediction year (i.e. the year we want to predict, not the year of the observation) on four panels of a
%single plot
%SYNTAX
%residsbytime2(Y,C,R.fsize,newfig)
%INPUTS
%Y is a matrix where each row is an observation, with columns:
% reefid year coral algae others
% for observations that have another observation one year earlier on the same
% reef
%C is an n x 1 vector of composite residuals for each of the observations
%in Y
%R is an n x 3 matrix of standardized univariate residuals for each of the
%observations in Y
%fsize (optional) is font size for labels
%if newfig (optional, default 1) is 1, plot on new figure
%OUTPUTS
%Four panels
%i. Boxplots of composite residuals by year (the starting year, in which X
%was observed)
%ii. Boxplots of each of the three standardized univariate residuals by
%year.
%USES
%panel_label.m

if nargin<4
    fsize=12;
end
if nargin<5
    newfig=1;
end

if newfig
    figure(1);
    clf;
end

titles={'(a) composite','(b) coral','(c) algae','(d) others'};
subplot(2,2,1);
boxplot(C,Y(:,2),'colors','k','symbol','k+','plotstyle','compact','jitter',0);
xlabel('Year','Fontsize',fsize);
ylabel('\itC_i','Fontsize',fsize);
panel_label(titles{1},fsize,0.1,0.1);
set(gca,'fontsize',fsize);

ylabels={'\itr_{i1}','\itr_{i2}','\itr_{i3}'};
for ii=1:3
    subplot(2,2,ii+1);
    boxplot(R(:,ii),Y(:,2),'colors','k','symbol','k+','plotstyle','compact','jitter',0);
    xlabel('Year','Fontsize',fsize);
    ylabel(ylabels{ii},'Fontsize',fsize);
    xl=get(gca,'xlim');
    yl=get(gca,'ylim');
    set(gca,'xlim',xl,'ylim',yl);
    panel_label(titles{ii+1},fsize,0.1,0.1);
    set(gca,'fontsize',fsize);
end