function [S,detS]=simplexgenvar(f,Gp,Gw)
%get a measure of spread for a stationary distribution on the simplex by
%quadrature
%SYNTAX
%[S,detS]=simplexgenvar(f,Gp,Gw)
%INPUTS
%f is a density function on the simplex evaluated at Gauss points
%Gp is a matrix of Gauss points (rows are points, cols are components)
%Gw is the Gauss weights for the points we used
%OUTPUTS
%S is a d-dimensional logratio covariance matrix (Aitchison p96), where
%d=D-1 and D is the number of components
%detS is the generalized variance of the estimated logratio covariance
%matrix
%USES
%alr.m

wf=Gw.*f;
D=size(Gp,2);
d=D-1;
wf=wf(:,ones(1,d));
y=alr(Gp);
wfy=wf.*y;
EY=sum(wfy);%vector of means of additive logratio transforms
S=zeros(d);
for i=1:d
    for j=i:d
        S(i,j)=sum(wf(:,1).*y(:,i).*y(:,j))-EY(i)*EY(j);%expectation of cross-product
        S(j,i)=S(i,j);
    end
end
detS=det(S);