function cx=simplexlocation(f,Gp,Gw)
%get a measure of location for a stationary distribution on the simplex by
%quadrature
%SYNTAX
%gx=simplexlocation(f,Gp,Gw)
%INPUTS
%f is a density function on the simplex evaluated at Gauss points
%Gp is a matrix of Gauss points (rows are points, cols are components)
%Gw is the Gauss weights for the points we used
%OUTPUTS
%cx is a vector containing the measure of location, with ith element
%g_i/(\sum_j g_j), where g_i is the geometric mean of the ith component of
%the distribution

wf=Gw.*f;
wf=wf(:,ones(1,size(Gp,2)));
cx=exp(sum(wf.*log(Gp)));%vector of geometric means
cx=cx/sum(cx);%closure