function [intf,cx,S,detS,rootdetS]=simplexsummary(eigvec,eigval,Gp,Gw)
%evaluate measures of location and spread of stationary distribution by
%quadrature
%SYNTAX
%[intf,cx,S,detS,rootdetS]=simplexsummary(eigvec,eigval,Gp,Gw)
%INPUTS
%eigvec is the eigenvectors of the matrix Dw as column vectors
%eigval is the corresponding eigenvalues as a diagonal matrix
%Gp is Gauss points (one row per point)
%Gw is the Gauss weights for the points we used
%OUTPUTS
%intf is integral of stationary distribution (should be 1)
%cx is measure of location (closure of geometric means). 
%S is logratio covariance matrix sigma
%detS is generalized variance of S
%rootdetS is square root of generalized variance
%USES
%simplexlocation.m
%simplexgenvar.m

[em,i]=max(diag(eigval));%index of largest eigenvalue (em is the value, should be close to 1)
fy=eigvec(:,i);%the corresponding eigenvector
f=fy/(Gw'*fy);%rescale the eigenvector so it integrates to 1 over the Gauss points
intf=sum(f.*Gw);
cx=simplexlocation(f,Gp,Gw);%approximate location measure
[S,detS]=simplexgenvar(f,Gp,Gw);%approximate spread measure
rootdetS=sqrt(detS);
